from .encoderPy import ENS, DEC

__author__ = 'AlmazCode'
__version__ = '1.0.3'
__email__ = 'diamondplay43@gmail.com'